@@ -2,21 +2,21 @@
 # Information about pre-loaded examples
 #------------------------------------------------
 
-exampleChoices <- c("Alber-Morgan (multiple baseline design)" = "AlberMorgan",
+exampleChoices <- c("Alber-Morgan (multiple baseline across participants)" = "AlberMorgan",
                     "Anglesea (ABAB design)" = "Anglesea", 
-                    "Barton-Arwood (multiple baseline design)" = "BartonArwood",
-                    "Bryant-et-al. (clustered multiple baseline)" = "Bryant2018",
-                    "Case-Harris-Graham (multiple baseline design)" = "CaseHarrisGraham",
-                    "Datchuk (multiple baseline design)" = "Datchuk",
-                    "Delemere-Dounavi (multiple baseline design)" = "DelemereDounavi",
-                    "Gunning-Espie (multiple baseline design)" = "GunningEspie",
+                    "Barton-Arwood (multiple baseline across participants)" = "BartonArwood",
+                    "Bryant-et-al. (clustered multiple baseline across participants)" = "Bryant2018",
+                    "Case-Harris-Graham (multiple probe across participants)" = "CaseHarrisGraham",
+                    "Datchuk (multiple probe across participants)" = "Datchuk",
+                    "Delemere-Dounavi (multiple baseline across participants)" = "DelemereDounavi",
+                    "Gunning-Espie (multiple baseline across participants)" = "GunningEspie",
                     "Lambert (ABAB design)" = "Lambert",
-                    "Laski (multiple baseline design)" = "Laski",
-                    "Peltier (multiple baseline design)" = "Peltier",
-                    "Rodgers (multiple baseline design)" = "Rodgers",
-                    "Rodriguez (multiple baseline design)" = "Rodriguez",
-                    "Saddler (multiple probe design)" = "Saddler",
-                    "Schutte (multiple baseline design)" = "Schutte",
+                    "Laski (multiple baseline across participants)" = "Laski",
+                    "Peltier (multiple probe across participants)" = "Peltier",
+                    "Rodgers (multiple baseline across participants)" = "Rodgers",
+                    "Rodriguez (multiple baseline across participants)" = "Rodriguez",
+                    "Saddler (multiple probe across participants)" = "Saddler",
+                    "Schutte (multiple baseline across participants)" = "Schutte",
                     "Thiemann-Goldstein (replicated multiple baseline across behaviors)" = "Thiemann2001",
                     "Thorne (ABAB design)" = "Thorne")
 
@@ -31,7 +31,7 @@ exampleMapping <- list(
                       vars = c("case","session","condition","outcome"),
                       phases = c("A","B")),
   Bryant2018 = list(design = "CMB",
-                    vars = c("Study_ID", "school", "case", "treatment", "session", "session_trt", "outcome", "session_c"),
+                    vars = c("Study_ID", "school", "group", "case", "treatment", "session", "session_trt", "outcome", "session_c"),
                     phases = c("baseline", "treatment")),
   CaseHarrisGraham = list(design = "MBP",
                           vars = c("case","session","condition","outcome"),
@@ -47,7 +47,9 @@ exampleMapping <- list(
                       phases = c("baseline","treatment", "follow-up")),
   Lambert = list(design = "TR",
                  vars = c("case","time","treatment","outcome"),
-                 phases = c("SSR","RC")),
+                 phases = c("SSR","RC"),
+                 filters = "measure",
+                 filter_measure = c("academic response", "disruptive behavior")),
   Laski = list(design = "MBP",
                vars = c("case","time","treatment","outcome"),
                phases = c(0,1)),
